diff --git a/COMET.Web.Common/Components/Selectors/DomainOfExpertiseSelector.razor b/COMET.Web.Common/Components/Selectors/DomainOfExpertiseSelector.razor
index c91fdd61..88cb68cf 100644
--- a/COMET.Web.Common/Components/Selectors/DomainOfExpertiseSelector.razor
+++ b/COMET.Web.Common/Components/Selectors/DomainOfExpertiseSelector.razor
@@ -32,7 +32,7 @@
@@ -48,6 +48,10 @@
@(domainOfExpertise.GetSelectorNameAndShortname())
}
+ else
+ {
+ @("Select a Domain Of Expertise")
+ }
-}
\ No newline at end of file
+}
diff --git a/COMET.Web.Common/ViewModels/Components/Selectors/IDomainOfExpertiseSelectorViewModel.cs b/COMET.Web.Common/ViewModels/Components/Selectors/IDomainOfExpertiseSelectorViewModel.cs
index 5af1a87b..97395f66 100644
--- a/COMET.Web.Common/ViewModels/Components/Selectors/IDomainOfExpertiseSelectorViewModel.cs
+++ b/COMET.Web.Common/ViewModels/Components/Selectors/IDomainOfExpertiseSelectorViewModel.cs
@@ -52,21 +52,26 @@ public interface IDomainOfExpertiseSelectorViewModel : IBelongsToIterationSelect
ISessionService SessionService { get; }
///
- /// Gets the from the current
+ /// Gets the from the current
///
DomainOfExpertise CurrentIterationDomain { get; set; }
///
- /// Gets or sets the callback that is executed when the property has changed
+ /// Gets or sets the callback that is executed when the property has changed
///
EventCallback OnSelectedDomainOfExpertiseChange { get; set; }
///
- /// Sets the property or resets its value
+ /// Gets or sets the condition to check if a null selection can be allowed
+ ///
+ bool AllowNullSelection { get; set; }
+
+ ///
+ /// Sets the property or resets its value
///
/// The condition to check if the value should be reset
- /// The to be set
- /// A
+ /// The to be set
+ /// A
Task SetSelectedDomainOfExpertiseOrReset(bool reset, DomainOfExpertise domainOfExpertise = null);
}
}
diff --git a/COMETwebapp/Components/ParameterEditor/BatchParameterEditor/BatchParameterEditor.razor b/COMETwebapp/Components/ParameterEditor/BatchParameterEditor/BatchParameterEditor.razor
index 64434d80..e3bd5b19 100644
--- a/COMETwebapp/Components/ParameterEditor/BatchParameterEditor/BatchParameterEditor.razor
+++ b/COMETwebapp/Components/ParameterEditor/BatchParameterEditor/BatchParameterEditor.razor
@@ -38,7 +38,7 @@ Copyright (c) 2024 Starion Group S.A.
@if (this.ViewModel.ParameterTypeSelectorViewModel.SelectedParameterType != null)
{
-
+
@@ -47,6 +47,23 @@ Copyright (c) 2024 Starion Group S.A.
+
+
+
Filter on Category:
+
+
+
+
+
+
+
Select a value:
x.ViewModel.ParameterTypeSelectorViewModel.SelectedParameterType,
x => x.ViewModel.OptionSelectorViewModel.SelectedOption,
- x => x.ViewModel.FiniteStateSelectorViewModel.SelectedActualFiniteState)
+ x => x.ViewModel.FiniteStateSelectorViewModel.SelectedActualFiniteState,
+ x => x.ViewModel.SelectedCategory,
+ x => x.ViewModel.DomainOfExpertiseSelectorViewModel.SelectedDomainOfExpertise)
.SubscribeAsync(_ => this.InvokeAsync(this.StateHasChanged)));
}
///
- /// Gets the group check value based on the given
+ /// Gets the group check value based on the given
///
/// The column group context
/// The check box value
@@ -106,9 +108,9 @@ private void GroupCheckBox_CheckedChanged(bool? value, GridDataColumnGroupRowTem
}
///
- /// Gets the s from the selected element name group
+ /// Gets the s from the selected element name group
///
- /// The
+ /// The
/// A collection of data items contained in the given group
private IEnumerable
diff --git a/COMET.Web.Common/ViewModels/Components/Selectors/DomainOfExpertiseSelectorViewModel.cs b/COMET.Web.Common/ViewModels/Components/Selectors/DomainOfExpertiseSelectorViewModel.cs
index 011f6074..5650f076 100644
--- a/COMET.Web.Common/ViewModels/Components/Selectors/DomainOfExpertiseSelectorViewModel.cs
+++ b/COMET.Web.Common/ViewModels/Components/Selectors/DomainOfExpertiseSelectorViewModel.cs
@@ -51,7 +51,7 @@ public class DomainOfExpertiseSelectorViewModel : BelongsToIterationSelectorView
/// Creates a new instance of
///
/// The
- /// The
+ /// The
public DomainOfExpertiseSelectorViewModel(ISessionService sessionService, ICDPMessageBus messageBus)
{
this.SessionService = sessionService;
@@ -62,7 +62,12 @@ public DomainOfExpertiseSelectorViewModel(ISessionService sessionService, ICDPMe
}
///
- /// Gets or sets the callback that is executed when the property has changed
+ /// Gets or sets the condition to check if a null selection can be allowed
+ ///
+ public bool AllowNullSelection { get; set; }
+
+ ///
+ /// Gets or sets the callback that is executed when the property has changed
///
public EventCallback OnSelectedDomainOfExpertiseChange { get; set; }
@@ -91,11 +96,11 @@ public DomainOfExpertise SelectedDomainOfExpertise
}
///
- /// Sets the property or resets its value
+ /// Sets the property or resets its value
///
/// The condition to check if the value should be reset
- /// The to be set
- /// A
+ /// The to be set
+ /// A
public async Task SetSelectedDomainOfExpertiseOrReset(bool reset, DomainOfExpertise domainOfExpertise = null)
{
switch (reset)
@@ -124,7 +129,7 @@ protected override void UpdateProperties()
///
/// Method executed when an iteration domain has changed
///
- /// The data
+ /// The data
private void OnDomainChanged(DomainChangedEvent domainChangedEvent)
{
if (domainChangedEvent.Iteration.Iid == this.CurrentIteration?.Iid)